@@ -117,7 +117,7 @@ atspi_accessible_dispose (GObject *object)
 
   /* TODO: Only fire if object not already marked defunct */
   memset (&e, 0, sizeof (e));
-  e.type = "object:state-change:defunct";
+  e.type = "object:state-changed:defunct";
   e.source = accessible;
   e.detail1 = 1;
   e.detail2 = 0;
